==> base_aux-0.2.19.1-py3-none-any.whl: base_aux/aux_text/test__0_pat_nums.py <==
import pytest
import re

from base_aux.aux_expect.m1_expect_aux import ExpectAux

from base_aux.aux_text.m0_patterns import *


# =====================================================================================================================
@pytest.mark.parametrize(
    argnames="source, fpoint, _EXP_int, _EXP_float, _EXP_both",
    argvalues=[
        # trash ----
        ("", None, (None, None), (None, None), (None, None)),
        ("hello", None, (None, None), (None, None), (None, None)),
        ("he.l,lo", None, (None, None), (None, None), (None, None)),

        ("11,22,33", None, (None, None), (None, None), (None, None)),
        ("11,22,33", ",", (None, None), (None, None), (None, None)),
        ("11.22.33", None, (None, None), (None, None), (None, None)),
        ("11.22.33", ",", (None, None), (None, None), (None, None)),

        # INT ------
        ("00100", None, ("00100", "00100"), (None, None), ("00100", "00100")),
        ("123", None, ("123", "123"), (None, None), ("123", "123")),
        ("a123b", None, (None, "123"), (None, None), (None, "123")),

        # FLOAT ----
        ("11,22", ".", (None, None), (None, None), (None, None)),
        ("11,22", ",", (None, None), ("11,22", "11,22"), ("11,22", "11,22")),
        ("11,22", None, (None, None), ("11,22", "11,22"), ("11,22", "11,22")),
        ("aa11,22bb", ",", (None, None), (None, "11,22"), (None, "11,22")),

        ("001.200", None, (None, None), ("001.200", "001.200"), ("001.200", "001.200")),
        ("11.22", None, (None, None), ("11.22", "11.22"), ("11.22", "11.22")),
        ("11.22", ",", (None, None), (None, None), (None, None)),

        # MINUS ----
        ("-123", None, ("-123", "-123"), (None, None), ("-123", "-123")),
        ("---123", None, (None, "-123"), (None, None), (None, "-123")),
        ("a-123a", None, (None, "-123"), (None, None), (None, "-123")),
        ("-a---123--a", None, (None, "-123"), (None, None), (None, "-123")),
        ("he-l,lo--11.22--=-asdf", None, (None, None), (None, "-11.22"), (None, "-11.22")),
    ]
)
def test___PatNumber(source, fpoint, _EXP_int, _EXP_float, _EXP_both):
    # INT -----
    match = re.fullmatch(PatNumberSingle(fpoint).INT_EXACT, source)
    ExpectAux(match and match[1]).check_assert(_EXP_int[0])

    match = re.fullmatch(PatNumberSingle(fpoint).INT_COVERED, source)
    ExpectAux(match and match[1]).check_assert(_EXP_int[1])

    # FLOAT -----
    match = re.fullmatch(PatNumberSingle(fpoint).FLOAT_EXACT, source)
    ExpectAux(match and match[1]).check_assert(_EXP_float[0])

    match = re.fullmatch(PatNumberSingle(fpoint).FLOAT_COVERED, source)
    ExpectAux(match and match[1]).check_assert(_EXP_float[1])

    # BOTH -----
    match = re.fullmatch(PatNumberSingle(fpoint).BOTH_EXACT, source)
    ExpectAux(match and match[1]).check_assert(_EXP_both[0])

    match = re.fullmatch(PatNumberSingle(fpoint).BOTH_COVERED, source)
    ExpectAux(match and match[1]).check_assert(_EXP_both[1])


# =====================================================================================================================

==> base_aux-0.3.1.1-py3-none-any.whl: base_aux/aux_text/test__0_pat_nums.py <==
import pytest
import re

from base_aux.base_lambdas.m1_lambda import *
from base_aux.aux_text.m0_patterns import *


# =====================================================================================================================
@pytest.mark.parametrize(
    argnames="source, fpoint, _EXP_int, _EXP_float, _EXP_both",
    argvalues=[
        # trash ----
        ("", None, (None, None), (None, None), (None, None)),
        ("hello", None, (None, None), (None, None), (None, None)),
        ("he.l,lo", None, (None, None), (None, None), (None, None)),

        ("11,22,33", None, (None, None), (None, None), (None, None)),
        ("11,22,33", ",", (None, None), (None, None), (None, None)),
        ("11.22.33", None, (None, None), (None, None), (None, None)),
        ("11.22.33", ",", (None, None), (None, None), (None, None)),

        # INT ------
        ("00100", None, ("00100", "00100"), (None, None), ("00100", "00100")),
        ("123", None, ("123", "123"), (None, None), ("123", "123")),
        ("a123b", None, (None, "123"), (None, None), (None, "123")),

        # FLOAT ----
        ("11,22", ".", (None, None), (None, None), (None, None)),
        ("11,22", ",", (None, None), ("11,22", "11,22"), ("11,22", "11,22")),
        ("11,22", None, (None, None), ("11,22", "11,22"), ("11,22", "11,22")),
        ("aa11,22bb", ",", (None, None), (None, "11,22"), (None, "11,22")),

        ("001.200", None, (None, None), ("001.200", "001.200"), ("001.200", "001.200")),
        ("11.22", None, (None, None), ("11.22", "11.22"), ("11.22", "11.22")),
        ("11.22", ",", (None, None), (None, None), (None, None)),

        # MINUS ----
        ("-123", None, ("-123", "-123"), (None, None), ("-123", "-123")),
        ("---123", None, (None, "-123"), (None, None), (None, "-123")),
        ("a-123a", None, (None, "-123"), (None, None), (None, "-123")),
        ("-a---123--a", None, (None, "-123"), (None, None), (None, "-123")),
        ("he-l,lo--11.22--=-asdf", None, (None, None), (None, "-11.22"), (None, "-11.22")),
    ]
)
def test___PatNumber(source, fpoint, _EXP_int, _EXP_float, _EXP_both):
    # INT -----
    match = re.fullmatch(Pat_NumberSingle(fpoint).INT_EXACT, source)
    Lambda(match and match[1]).expect__check_assert(_EXP_int[0])

    match = re.fullmatch(Pat_NumberSingle(fpoint).INT_COVERED, source)
    Lambda(match and match[1]).expect__check_assert(_EXP_int[1])

    # FLOAT -----
    match = re.fullmatch(Pat_NumberSingle(fpoint).FLOAT_EXACT, source)
    Lambda(match and match[1]).expect__check_assert(_EXP_float[0])

    match = re.fullmatch(Pat_NumberSingle(fpoint).FLOAT_COVERED, source)
    Lambda(match and match[1]).expect__check_assert(_EXP_float[1])

    # BOTH -----
    match = re.fullmatch(Pat_NumberSingle(fpoint).BOTH_EXACT, source)
    Lambda(match and match[1]).expect__check_assert(_EXP_both[0])

    match = re.fullmatch(Pat_NumberSingle(fpoint).BOTH_COVERED, source)
    Lambda(match and match[1]).expect__check_assert(_EXP_both[1])


# =====================================================================================================================
